==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/apicenter/kotlin/ApiVersion.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.apicenter.kotlin

import com.pulumi.azurenative.apicenter.kotlin.outputs.SystemDataResponse
import com.pulumi.azurenative.apicenter.kotlin.outputs.SystemDataResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit

/**
 * Builder for [ApiVersion].
 */
@PulumiTagMarker
public class ApiVersionResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: ApiVersionArgs = ApiVersionArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend ApiVersionArgsBuilder.() -> Unit) {
        val builder = ApiVersionArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): ApiVersion {
        val builtJavaResource = com.pulumi.azurenative.apicenter.ApiVersion(
            this.name,
            this.args.toJava(),
            this.opts.toJava(),
        )
        return ApiVersion(builtJavaResource)
    }
}

/**
 * API version entity.
 * Azure REST API version: 2024-03-01.
 * ## Example Usage
 * ### ApiVersions_CreateOrUpdate
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var apiVersion = new AzureNative.ApiCenter.ApiVersion("apiVersion", new()
 *     {
 *         ApiName = "echo-api",
 *         LifecycleStage = "production",
 *         ResourceGroupName = "contoso-resources",
 *         ServiceName = "contoso",
 *         Title = "2023-01-01",
 *         VersionName = "2023-01-01",
 *         WorkspaceName = "default",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/apicenter/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := apicenter.NewApiVersion(ctx, "apiVersion", &apicenter.ApiVersionArgs{
 * 			ApiName:           pulumi.String("echo-api"),
 * 			LifecycleStage:    pulumi.String("production"),
 * 			ResourceGroupName: pulumi.String("contoso-resources"),
 * 			ServiceName:       pulumi.String("contoso"),
 * 			Title:             pulumi.String("2023-01-01"),
 * 			VersionName:       pulumi.String("2023-01-01"),
 * 			WorkspaceName:     pulumi.String("default"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.apicenter.ApiVersion;
 * import com.pulumi.azurenative.apicenter.ApiVersionArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var apiVersion = new ApiVersion("apiVersion", ApiVersionArgs.builder()
 *             .apiName("echo-api")
 *             .lifecycleStage("production")
 *             .resourceGroupName("contoso-resources")
 *             .serviceName("contoso")
 *             .title("2023-01-01")
 *             .versionName("2023-01-01")
 *             .workspaceName("default")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:apicenter:ApiVersion 2023-01-01 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.ApiCenter/services/{serviceName}/workspaces/{workspaceName}/apis/{apiName}/versions/{versionName}
 * ```
 */
public class ApiVersion internal constructor(
    override val javaResource: com.pulumi.azurenative.apicenter.ApiVersion,
) : KotlinCustomResource(javaResource, ApiVersionMapper) {
    /**
     * Current lifecycle stage of the API.
     */
    public val lifecycleStage: Output<String>
        get() = javaResource.lifecycleStage().applyValue({ args0 -> args0 })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Azure Resource Manager metadata containing createdBy and modifiedBy information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 -> args0.let({ args0 -> toKotlin(args0) }) })

    /**
     * API version title.
     */
    public val title: Output<String>
        get() = javaResource.title().applyValue({ args0 -> args0 })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object ApiVersionMapper : ResourceMapper<ApiVersion> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.apicenter.ApiVersion::class == javaResource::class

    override fun map(javaResource: Resource): ApiVersion = ApiVersion(
        javaResource as
            com.pulumi.azurenative.apicenter.ApiVersion,
    )
}

/**
 * @see [ApiVersion].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [ApiVersion].
 */
public suspend fun apiVersion(name: String, block: suspend ApiVersionResourceBuilder.() -> Unit):
    ApiVersion {
    val builder = ApiVersionResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [ApiVersion].
 * @param name The _unique_ name of the resulting resource.
 */
public fun apiVersion(name: String): ApiVersion {
    val builder = ApiVersionResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/apicenter/kotlin/ApiVersion.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.apicenter.kotlin

import com.pulumi.azurenative.apicenter.kotlin.outputs.SystemDataResponse
import com.pulumi.azurenative.apicenter.kotlin.outputs.SystemDataResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit

/**
 * Builder for [ApiVersion].
 */
@PulumiTagMarker
public class ApiVersionResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: ApiVersionArgs = ApiVersionArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend ApiVersionArgsBuilder.() -> Unit) {
        val builder = ApiVersionArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): ApiVersion {
        val builtJavaResource = com.pulumi.azurenative.apicenter.ApiVersion(
            this.name,
            this.args.toJava(),
            this.opts.toJava(),
        )
        return ApiVersion(builtJavaResource)
    }
}

/**
 * API version entity.
 * Azure REST API version: 2024-03-01.
 * Other available API versions: 2024-03-15-preview.
 * ## Example Usage
 * ### ApiVersions_CreateOrUpdate
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var apiVersion = new AzureNative.ApiCenter.ApiVersion("apiVersion", new()
 *     {
 *         ApiName = "echo-api",
 *         LifecycleStage = AzureNative.ApiCenter.LifecycleStage.Production,
 *         ResourceGroupName = "contoso-resources",
 *         ServiceName = "contoso",
 *         Title = "2023-01-01",
 *         VersionName = "2023-01-01",
 *         WorkspaceName = "default",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/apicenter/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := apicenter.NewApiVersion(ctx, "apiVersion", &apicenter.ApiVersionArgs{
 * 			ApiName:           pulumi.String("echo-api"),
 * 			LifecycleStage:    pulumi.String(apicenter.LifecycleStageProduction),
 * 			ResourceGroupName: pulumi.String("contoso-resources"),
 * 			ServiceName:       pulumi.String("contoso"),
 * 			Title:             pulumi.String("2023-01-01"),
 * 			VersionName:       pulumi.String("2023-01-01"),
 * 			WorkspaceName:     pulumi.String("default"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.apicenter.ApiVersion;
 * import com.pulumi.azurenative.apicenter.ApiVersionArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var apiVersion = new ApiVersion("apiVersion", ApiVersionArgs.builder()
 *             .apiName("echo-api")
 *             .lifecycleStage("production")
 *             .resourceGroupName("contoso-resources")
 *             .serviceName("contoso")
 *             .title("2023-01-01")
 *             .versionName("2023-01-01")
 *             .workspaceName("default")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:apicenter:ApiVersion 2023-01-01 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.ApiCenter/services/{serviceName}/workspaces/{workspaceName}/apis/{apiName}/versions/{versionName}
 * ```
 */
public class ApiVersion internal constructor(
    override val javaResource: com.pulumi.azurenative.apicenter.ApiVersion,
) : KotlinCustomResource(javaResource, ApiVersionMapper) {
    /**
     * Current lifecycle stage of the API.
     */
    public val lifecycleStage: Output<String>
        get() = javaResource.lifecycleStage().applyValue({ args0 -> args0 })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Azure Resource Manager metadata containing createdBy and modifiedBy information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 -> args0.let({ args0 -> toKotlin(args0) }) })

    /**
     * API version title.
     */
    public val title: Output<String>
        get() = javaResource.title().applyValue({ args0 -> args0 })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object ApiVersionMapper : ResourceMapper<ApiVersion> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.apicenter.ApiVersion::class == javaResource::class

    override fun map(javaResource: Resource): ApiVersion = ApiVersion(
        javaResource as
            com.pulumi.azurenative.apicenter.ApiVersion,
    )
}

/**
 * @see [ApiVersion].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [ApiVersion].
 */
public suspend fun apiVersion(name: String, block: suspend ApiVersionResourceBuilder.() -> Unit):
    ApiVersion {
    val builder = ApiVersionResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [ApiVersion].
 * @param name The _unique_ name of the resulting resource.
 */
public fun apiVersion(name: String): ApiVersion {
    val builder = ApiVersionResourceBuilder()
    builder.name(name)
    return builder.build()
}
